﻿using DataSharing.CityStateDataExchange;
using DataSharing.Police110.DaoShu110;
using DataSharing.Police110.DCJT110;
using DataSharing.Province;
using DataSharing.RawData;
using DataSharing.Share.Dtos.Province.HuiJu;
using DataSharing.Share.Dtos.Province.XieTong.Send;
using DataSharing.YiBin.Enterprise;
using DataSharing.YiBin.ZzptPlatformsYB;
using DotNetCore.CAP;
using Hotline.Share.Dtos.Knowledge;
using Hotline.Share.Dtos.Order;
using Hotline.Share.Dtos.TrCallCenter;
using Hotline.Share.Enums.Order;
using MapsterMapper;
using Microsoft.Extensions.Logging;
using XF.Domain.Dependency;
using XF.Domain.Exceptions;
using XF.Domain.Repository;

namespace DataSharing.Application.Receivers
{
    public class ProvinceReceiver : ICapSubscribe, IScopeDependency
    {
        #region 注入
        private readonly IMapper _mapper;
        private readonly ILogger<ProvinceReceiver> _logger;
        private readonly IRepository<DsOrder> _dsOrderRepository;
        private readonly ISharingConfigurationManager _sharingConfigurationManager;
        private readonly IProvinceService _provinceService;
        private readonly IDaoShuService _daoShuService;
        private readonly IDcjtService _dcjtService;
        private readonly IEnterpriseService _enterpriseService;
        private readonly IZzptService _zzptService;
        private readonly ICityStateDataExchangeService _cityStateDataExchangeService;
        private readonly IRepository<DsOrderSend> _orderSendRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="mapper"></param>
        /// <param name="logger"></param>
        /// <param name="dsOrderRepository"></param>
        /// <param name="sharingConfigurationManager"></param>
        /// <param name="provinceService"></param>
        /// <param name="daoShuService"></param>
        /// <param name="dcjtService"></param>
        /// <param name="enterpriseService"></param>
        /// <param name="zzptService"></param>
        /// <param name="cityStateDataExchangeService"></param>
        /// <param name="orderSendRepository"></param>
        public ProvinceReceiver(IMapper mapper, ILogger<ProvinceReceiver> logger,
             IRepository<DsOrder> dsOrderRepository,
             ISharingConfigurationManager sharingConfigurationManager,
             IProvinceService provinceService,
              IDaoShuService daoShuService,
              IDcjtService dcjtService,
              IEnterpriseService enterpriseService,
              IZzptService zzptService,
              ICityStateDataExchangeService cityStateDataExchangeService,
              IRepository<DsOrderSend> orderSendRepository)
        {
            _mapper = mapper;
            _logger = logger;
            _dsOrderRepository = dsOrderRepository;
            _sharingConfigurationManager = sharingConfigurationManager;
            _provinceService = provinceService;
            _daoShuService = daoShuService;
            _dcjtService = dcjtService;
            _enterpriseService = enterpriseService;
            _zzptService = zzptService;
            _cityStateDataExchangeService = cityStateDataExchangeService;
            _orderSendRepository = orderSendRepository;
        }
        #endregion

        #region 协同-第一批次

        /// <summary>
        /// 退回申请
        /// </summary>
        /// <param name="dtos"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderFlowPrevious)]
        public async Task GetCaseBackApplyAsync(PublishOrderSendBackDto dtos, CancellationToken cancellationToken)
        {
            if (dtos != null && dtos.SendDatas != null)
            {
                //调用省退回申请
                await _provinceService.GetCaseBackApplyAsync(dtos, cancellationToken);
            }
        }

        /// <summary>
        /// 服务工单督办过程
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderSuperviseCourse)]
        public async Task SendSuperviseProcessInfoAsync(PublishSuperviseDto dto, CancellationToken cancellationToken)
        {
            //工单是省上派下来的，才能进行督办回复
            if (dto.Order.Source == ESource.ProvinceStraight)
            {
                //服务工单督办过程
                await _provinceService.SendSuperviseProcessInfoAsync(dto, cancellationToken);
            }
        }

        /// <summary>
        /// 服务工单督办结果
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderSuperviseResult)]
        public async Task SendSuperviseResultInfoAsync(PublishSuperviseDto dto, CancellationToken cancellationToken)
        {
            //工单是省上派下来的，才能进行督办回复
            if (dto.Order.Source == ESource.ProvinceStraight)
            {
                //服务工单督办结果
                await _provinceService.SendSuperviseResultInfoAsync(dto, cancellationToken);
            }
        }

        /// <summary>
        /// 工单发起甄别
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderScreenApply)]
        public async Task ScreenCaseInfoSendAsync(PublishScreenDto dto, CancellationToken cancellationToken)
        {
            //如果是省上派下来的工单，才能调发起甄别的接口
            if (dto.Order.Source == ESource.ProvinceStraight && dto.Order.IsProvince)
            {
                //工单发起甄别
                await _provinceService.ScreenCaseInfoSendAsync(dto, cancellationToken);
            }
        }

        /// <summary>
        /// 服务工单申请延时
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderApplyDelay)]
        public async Task DelayCaseInfoSendAsync(PublishOrderDelayDto dto, CancellationToken cancellationToken)
        {
            //服务工单申请延时
            await _provinceService.DelayCaseInfoSendAsync(dto, cancellationToken);
        }

        #endregion

        #region 汇聚-第二批次

        /// <summary>
        /// 热线工单流程开启 --服务工单受理
        /// </summary>
        /// <param name="pushdto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderFlowStarted)]
        public async Task OrderFlowStartedAsync(PublishCallRecrodDto pushdto, CancellationToken cancellationToken)
        {
            var dto = pushdto.Order;
            var dataOrder = await _dsOrderRepository.GetAsync(p => p.OrderId == dto.Id, cancellationToken);

            #region 本地保存工单基础数据
            //本地保存工单基础数据---存在修改，不存在新增
            if (dataOrder == null)
            {
                dataOrder = new()
                {
                    OrderId = dto.Id,
                    OrderNo = dto.No,
                    ProvinceNo = dto.ProvinceNo,
                    WorkflowId = dto.WorkflowId,
                    Password = dto.Password,
                    Title = dto.Title,
                    FromName = dto.FromName,
                    Contact = dto.Contact,
                    Content = dto.Content,
                    CaseDate = Convert.ToDateTime(dto.CreationTime),
                    Source = dto.Source.ToString(),
                    CaseSource = dto.SourceChannel,
                    CaseSourceCode = dto.SourceChannelCode,
                    HotspotId = dto.HotspotId,
                    HotspotName = dto.HotspotName,
                    HotspotSpliceName = dto.HotspotSpliceName,
                    ExpiredTime = dto.ExpiredTime,
                    CaseType = dto.AcceptType,
                    CaseTypeCode = dto.AcceptTypeCode,
                    AllDuration = 0,
                    IsProvince = dto.IsProvince,
                    HandleState = "办理中",
                    StartTime = dto.StartTime,
                    CallId = dto.CallId,
                    FileJson = _mapper.Map<List<DataSharing.Share.Dtos.FileJson>>(dto.FileJson)
                };

                await _dsOrderRepository.AddAsync(dataOrder, cancellationToken);
            }
            else
            {
                dataOrder.ProvinceNo = dto.ProvinceNo;
                dataOrder.WorkflowId = dto.WorkflowId;
                dataOrder.Password = dto.Password;
                dataOrder.Title = dto.Title;
                dataOrder.FromName = dto.FromName;
                dataOrder.Contact = dto.Contact;
                dataOrder.Content = dto.Content;
                dataOrder.CaseDate = Convert.ToDateTime(dto.CreationTime);
                dataOrder.Source = dto.Source.ToString();
                dataOrder.CaseSource = dto.SourceChannel;
                dataOrder.CaseSourceCode = dto.SourceChannelCode;
                dataOrder.HotspotId = dto.HotspotId;
                dataOrder.HotspotName = dto.HotspotName;
                dataOrder.HotspotSpliceName = dto.HotspotSpliceName;
                dataOrder.ExpiredTime = dto.ExpiredTime;
                dataOrder.CaseType = dto.AcceptType;
                dataOrder.CaseTypeCode = dto.AcceptTypeCode;
                dataOrder.AllDuration = 0;
                dataOrder.IsProvince = dto.IsProvince;
                dataOrder.HandleState = "办理中";
                dataOrder.StartTime = dto.StartTime;
                dataOrder.CallId = dto.CallId;
                dataOrder.FileJson = _mapper.Map<List<DataSharing.Share.Dtos.FileJson>>(dto.FileJson);

                await _dsOrderRepository.UpdateAsync(dataOrder, cancellationToken);
            }
            #endregion

            #region 工单推送数据处理
            var orderSend = await _orderSendRepository.GetAsync(p => p.OrderId == dto.Id, cancellationToken);
            if (orderSend != null)
            {
                orderSend.CaseDate = Convert.ToDateTime(dto.CreationTime);
                orderSend.StartTime = dto.StartTime;
                orderSend.CallId = dto.CallId;
                orderSend.Source = dto.Source.ToString();
                orderSend.CaseSource = dto.SourceChannel;
                orderSend.CaseSourceCode = dto.SourceChannelCode;
                orderSend.ExpiredTime = dto.ExpiredTime;
                await _orderSendRepository.UpdateAsync(orderSend, cancellationToken);
            }
            else
            {
                orderSend = new DsOrderSend()
                {
                    OrderId = dto.Id,
                    OrderNo = dto.No,
                    ProvinceNo = dto.ProvinceNo,
                    CaseDate = Convert.ToDateTime(dto.CreationTime),
                    StartTime = dto.StartTime,
                    CallId = dto.CallId,
                    Source = dto.Source.ToString(),
                    CaseSource = dto.SourceChannel,
                    CaseSourceCode = dto.SourceChannelCode,
                    ExpiredTime = dto.ExpiredTime
                };
                await _orderSendRepository.AddAsync(orderSend, cancellationToken);
            }
            #endregion

            //热线工单流程开启 --服务工单受理
            await _provinceService.OrderFlowStartedAsync(pushdto, cancellationToken);

            //是否需要往第三方推送
            await OrderDispatchAsync(new OrderFlowDto { Order = pushdto.Order, WorkflowTrace = pushdto.WorkflowTrace, ExpiredTimeChanged = false }, cancellationToken);

        }

        /// <summary>
        /// 热线工单期满时间变更--推送服务工单受理
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderExpiredTimeUpdate)]
        public async Task HotlineOrderFlowRecalledAsync(OrderDto dto, CancellationToken cancellationToken)
        {
            //调用热线工单期满时间变更--推送服务工单受理
            await _provinceService.HotlineOrderFlowRecalledAsync(dto, cancellationToken);

            //修改工单的期满时间
            var dataOrder = await _dsOrderRepository.GetAsync(p => p.OrderId == dto.Id, cancellationToken);
            if (dataOrder != null)
            {
                dataOrder.ExpiredTime = dto.ExpiredTime;
                await _dsOrderRepository.UpdateAsync(dataOrder, cancellationToken);
            }

            //修改工单推送表期满时间
            var orderSend = await _orderSendRepository.GetAsync(p => p.OrderId == dto.Id, cancellationToken);
            if (orderSend != null)
            {
                orderSend.ExpiredTime = dto.ExpiredTime;
                await _orderSendRepository.UpdateAsync(orderSend, cancellationToken);
            }
        }

        /// <summary>
        /// 热线工单办理---服务工单处理/服务工单交办处理过程
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderFlowHandled)]
        public async Task SubmitCaseProcessAsync(OrderFlowDto dto, CancellationToken cancellationToken)
        {
            if (string.IsNullOrEmpty(dto.Order.AreaCode) || dto.Order.AreaCode.Contains("519"))
                dto.Order.AreaCode = _sharingConfigurationManager.GetCityCode();

            if (string.IsNullOrEmpty(dto.WorkflowTrace.HandlerOrgAreaCode))
            {
                dto.WorkflowTrace.HandlerOrgAreaCode = dto.Order.AreaCode;
                if (dto.WorkflowTrace.HandlerOrgAreaCode.Length > 6)
                    dto.WorkflowTrace.HandlerOrgAreaCode = dto.WorkflowTrace.HandlerOrgAreaCode.Substring(0, 6);
            }

            //调用 热线工单办理---服务工单处理/服务工单交办处理过程
            await _provinceService.SubmitCaseProcessAsync(dto, cancellationToken);

            //是否需要往第三方推送
            await OrderDispatchAsync(dto, cancellationToken);
        }

        /// <summary>
        /// 回访完成---服务工单回访评价/服务工单交办评价
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderVisited)]
        public async Task SubmitVisitInfoAsync(PublishVisitDto dto, CancellationToken cancellationToken)
        {
            await _provinceService.SubmitVisitInfoDataAsync(dto, cancellationToken);

            //组装处理110数据
            if (dto.Order.Source == ESource.Police110)
            {
                //宜宾
                if (_sharingConfigurationManager.IsCity(ConfigurationConsts.YiBin))
                {
                    await _daoShuService.VisitDs(dto, cancellationToken);
                }

                //自贡
                if (_sharingConfigurationManager.IsCity(ConfigurationConsts.ZiGong))
                {
                    await _dcjtService.VisitDcjt(dto, cancellationToken);
                }
            }


        }

        /// <summary>
        /// 甄别通过---服务工单回访评价//服务工单交办评价
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderScreenApplyed)]
        public async Task SubmitOrderScreenSuccessAsync(PublishVisitDto dto, CancellationToken cancellationToken)
        {
            //推省上
            await _provinceService.SubmitVisitInfoDataAsync(dto, cancellationToken);

            //组装处理110数据
            if (dto.Order.Source == ESource.Police110)
            {
                //宜宾
                if (_sharingConfigurationManager.IsCity(ConfigurationConsts.YiBin))
                {
                    await _daoShuService.VisitDs(dto, cancellationToken);
                }

                //自贡
                if (_sharingConfigurationManager.IsCity(ConfigurationConsts.ZiGong))
                {
                    await _dcjtService.VisitDcjt(dto, cancellationToken);
                }
            }
        }

        /// <summary>
        /// 热线工单归档---服务工单结果/服务工单交办处理结果
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderFiled)]
        public async Task OrderFiledAsync(OrderFlowDto dto, CancellationToken cancellationToken)
        {
            #region 工单推送数据处理
            //工单推送数据处理
            var orderSend = await _orderSendRepository.GetAsync(p => p.OrderId == dto.Order.Id, cancellationToken);
            if (orderSend != null)
            {
                orderSend.HandleState = "办理完成";
                orderSend.ActualHandleTime = dto.Order.ActualHandleTime;
                orderSend.FiledTime = dto.Order.FiledTime;
                orderSend.CaseDate = Convert.ToDateTime(dto.Order.CreationTime);
                orderSend.StartTime = dto.Order.StartTime;
                orderSend.CallId = dto.Order.CallId;
                orderSend.Source = dto.Order.Source.ToString();
                orderSend.CaseSource = dto.Order.SourceChannel;
                orderSend.CaseSourceCode = dto.Order.SourceChannelCode;
                orderSend.ExpiredTime = dto.Order.ExpiredTime;
                await _orderSendRepository.UpdateAsync(orderSend, cancellationToken);
            }
            else
            {
                orderSend = new DsOrderSend()
                {
                    OrderId = dto.Order.Id,
                    OrderNo = dto.Order.No,
                    ProvinceNo = dto.Order.ProvinceNo,
                    CaseDate = Convert.ToDateTime(dto.Order.CreationTime),
                    StartTime = dto.Order.StartTime,
                    CallId = dto.Order.CallId,
                    Source = dto.Order.Source.ToString(),
                    CaseSource = dto.Order.SourceChannel,
                    CaseSourceCode = dto.Order.SourceChannelCode,
                    ExpiredTime = dto.Order.ExpiredTime,
                    HandleState = "办理完成",
                    ActualHandleTime = dto.Order.ActualHandleTime,
                    FiledTime = dto.Order.FiledTime,
                };
                await _orderSendRepository.AddAsync(orderSend, cancellationToken);
            }
            #endregion

            //推省上
            await _provinceService.OrderFiledAsync(dto, cancellationToken);

            //市州互转推送办结结果
            if (dto.Order.Source >= ESource.CityDataExchangeLz && dto.Order.Source < ESource.ConvergenceMedia)
                await _cityStateDataExchangeService.UndertakAdviceAsync(dto.Order, cancellationToken);

            //处理宜宾的推送业务
            if (_sharingConfigurationManager.IsCity(ConfigurationConsts.YiBin))
            {
                //如果是110来源工单，如果非警情退回未true,则退回100，否则就写入办理记录
                if (dto.Order.Source == ESource.Police110)
                {
                    if (dto.IsNonPoliceReturn == true)
                        await _daoShuService.ReturnPoliceDsAsync(dto.Order, cancellationToken);
                    else
                        await _daoShuService.InitPoliceSendChainDealDsAsync(dto, cancellationToken);

                }

                //综治平台推送办理结果
                if (dto.Order.Source == ESource.ZZPT)
                {
                    await _zzptService.InitZzptPlatformsDetailAsync(dto, cancellationToken);
                }
            }

            //处理自贡的推送业务
            if (_sharingConfigurationManager.IsCity(ConfigurationConsts.ZiGong))
            {
                //如果是110来源工单，如果非警情退回未true,则退回100，否则就写入办理记录
                if (dto.Order.Source == ESource.Police110)
                {
                    if (dto.IsNonPoliceReturn == true)
                        await _dcjtService.ReturnPoliceDcjtAsync(dto.Order, cancellationToken);
                    else
                        await _dcjtService.InitPoliceSendChainDealDcjtAsync(dto, cancellationToken);
                }
            }

        }

        /// <summary>
        /// 挂电话推送----电话记录
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineCallBye)]
        public async Task SubmitCaseRecordAsync(PublishCallRecrodDto dto, CancellationToken cancellationToken)
        {
            await _provinceService.SubmitCaseRecordAsync(dto, cancellationToken);
        }

        /// <summary>
        /// 关联工单了推送----电话记录
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineCallConnectWithOrder)]
        public async Task SubmitCaseRecordOrderAsync(PublishCallRecrodDto dto, CancellationToken cancellationToken)
        {
            await _provinceService.SubmitCaseRecordOrderAsync(dto, cancellationToken);
        }

        /// <summary>
        /// 统计数据
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task SubmitCaseTotalAsync(SubmitCaseTotalInfo dto, CancellationToken cancellationToken)
        {
            await _provinceService.SubmitCaseTotalAsync(dto, cancellationToken);
        }

        #endregion

        #region 协同-第三批次

        /// <summary>
        /// 上报补充诉求
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task SupplyCaseInfoSendAsync(SupplyCaseInfoSendInfo dto, CancellationToken cancellationToken)
        {
            //调用上报补充诉求
            await _provinceService.SupplyCaseInfoSendAsync(dto, cancellationToken);
        }

        /// <summary>
        /// 撤单
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderFlowRecalled)]
        public async Task RevokeOrderAsync(PublishSpecialDto dto, CancellationToken cancellationToken)
        {
            //宜宾业务处理
            if (_sharingConfigurationManager.IsCity(ConfigurationConsts.YiBin))
            {
                //企业服务
                if (dto.Special.OrgId == "001181")
                {
                    await _enterpriseService.EnterpriseRevokeOrderAsync(dto, cancellationToken);
                }
            }
            //省12345
            if (dto.Special.OrgId == "001171" || dto.Special.OrgId == "001178")
            {
                //调用省撤单
                await _provinceService.RevokeOrderAsync(dto, cancellationToken);
            }
        }

        /// <summary>
        /// 服务工单催单
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderUrgeInform)]
        public async Task SendRemindCaseInfoAsync(PublishUrgeDto dto, CancellationToken cancellationToken)
        {
            //被催办部门为省上，才能调用接口
            if (dto.Urge.OrgId == "001171" || dto.Urge.OrgId == "001178")
            {
                //调用服务工单催单
                await _provinceService.SendRemindCaseInfoAsync(dto, cancellationToken);
            }
        }

        /// <summary>
        /// 接收发布数据
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderPublishOrder)]
        public async Task PublishOrderAsync(PublishPublishOrderDto dto, CancellationToken cancellationToken)
        {
            //修改工单基础数据
            var dataOrder = await _dsOrderRepository.GetAsync(p => p.OrderId == dto.Order.Id, cancellationToken);
            if (dataOrder != null)
            {
                dataOrder.IsPublish = dto.PublishState == true ? DataSharing.Share.Enums.EDsPublishState.Open : DataSharing.Share.Enums.EDsPublishState.NotPublic;
                dataOrder.PublishDate = dto.CreationTime;
                dataOrder.ArrangeTitle = dto.ArrangeTitle;
                dataOrder.ArrangeContent = dto.ArrangeContent;
                dataOrder.ArrangeOpinion = dto.ArrangeOpinion;
                await _dsOrderRepository.UpdateAsync(dataOrder, cancellationToken);
            }

            //调用接收发布数据
            await _provinceService.PublishOrderAsync(dto, cancellationToken);

        }

        /// <summary>
        /// 接收发布的时候生成的待回访部门数据
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderVisitedWeb)]
        public async Task PublishVisitAllAsync(PublishVisitAllDto dto, CancellationToken cancellationToken)
        {
            //调用接收发布的时候生成的待回访部门数据
            await _provinceService.PublishVisitAllAsync(dto, cancellationToken);
        }

        /// <summary>
        /// 市州互转
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderTranspondCity)]
        public async Task TranspondCityAsync(OrderDto dto, CancellationToken cancellationToken)
        {
            //泸州市州数据提交
            if (dto.Transpond == true)
            {
                //判断推送市州
                string PlatformSource = "";
                switch (dto.TranspondCityValue)
                {
                    case "TranspondCityLZ12345":  //转泸州12345
                        PlatformSource = "CityDataExchangeLz";
                        break;
                    case "TranspondCityZG12345"://转自贡12345
                        PlatformSource = "CityDataExchangeZG";
                        break;
                    case "TranspondCityYB12345"://转宜宾12345
                        PlatformSource = "CityDataExchangeYB";
                        break;
                    case "TranspondCityNJ12345"://转内江12345
                        PlatformSource = "CityDataExchangeNJ";
                        break;

                    default:
                        break;
                }
                //数据推送
                await _cityStateDataExchangeService.InitCityDataAsync(dto, PlatformSource, cancellationToken);
            }
        }
        #endregion

        #region 汇聚-第四批次

        #region 知识库
        /// <summary>
        /// 知识库上报
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineKnowledgeAdd)]
        public async Task GetKnowledgeInfoSendAsync(KnowledgeSendDto dto, CancellationToken cancellationToken)
        {
            //调用知识库上报
            await _provinceService.GetKnowledgeInfoSendAsync(dto, cancellationToken);

        }

        /// <summary>
        /// 知识库变更
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineKnowledgeUpdate)]
        public async Task GetKnowledgeInfoUpdateAsync(KnowledgeSendDto dto, CancellationToken cancellationToken)
        {
            //调用知识库变更
            await _provinceService.GetKnowledgeInfoUpdateAsync(dto, cancellationToken);
        }

        /// <summary>
        /// 知识库下架
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        /// <exception cref="UserFriendlyException"></exception>
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineKnowledgeRemove)]
        public async Task GetKnowledgeInfoAbandonAsync(KnowledgeSendDto dto, CancellationToken cancellationToken)
        {
            //调用知识库下架
            await _provinceService.GetKnowledgeInfoAbandonAsync(dto, cancellationToken);
        }
        #endregion

        /// <summary>
        /// 实时服务上报
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task SendRealTimeStatusAsync(SendRealTimeStatusInfo dto, CancellationToken cancellationToken)
        {
            //调用实时服务上报
            await _provinceService.SendRealTimeStatusAsync(dto, cancellationToken);
        }
        #endregion

        /// <summary>
        /// 派单是判断需要往第三方推送数据
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        private async Task OrderDispatchAsync(OrderFlowDto dto, CancellationToken cancellationToken)
        {
            if (dto.WorkflowTrace.NextHandlers != null && dto.WorkflowTrace.NextHandlers.Count > 0)
            {
                foreach (var item in dto.WorkflowTrace.NextHandlers)
                {
                    if (!string.IsNullOrEmpty(item.Key))
                    {
                        //是否向省上派单，不用区分市州，根据部门Code上传
                        if (item.Key == _sharingConfigurationManager.GetProvinceOrgCode() || item.Key == _sharingConfigurationManager.GetProvinceAssignmentOrgCode())
                            await _provinceService.SendCaseInfoDataAsync(dto.Order, cancellationToken);

                        //todo 判断不同地市业务逻辑
                        //处理宜宾的推送业务
                        if (_sharingConfigurationManager.IsCity(ConfigurationConsts.YiBin))
                        {
                            //需要判断是否需要往110推送
                            if (item.Key == _sharingConfigurationManager.GetPoliceOrgCode())
                                //写入110本地数据库
                                await _daoShuService.InitPoliceSendChainAlarmDsAsync(dto.Order, cancellationToken);

                            //需要判断是否需要往企业专班提交数据
                            if (item.Key == "001181")
                                //企业专班提交数据
                                await _enterpriseService.InitEnterpriseDataAsync(dto.Order, cancellationToken);

                            //综治平台
                            if (item.Key == "001143")
                                await _zzptService.InitZzptPlatformsAsync(dto.Order, cancellationToken);
                        }


                        //处理自贡的推送业务
                        if (_sharingConfigurationManager.IsCity(ConfigurationConsts.YiBin))
                        {
                            //需要判断是否需要往110推送
                            if (item.Key == _sharingConfigurationManager.GetPoliceOrgCode())
                                //写入110本地数据库
                                await _dcjtService.InitPoliceSendChainAlarmDcjtAsync(dto.Order, cancellationToken);
                        }
                    }
                }
            }
        }
    }
}
