﻿using DataSharing.SendTask.OtherPlatforms;
using DataSharing.Share.Enums;
using MapsterMapper;
using Microsoft.Extensions.Logging;
using Quartz;
using XF.Domain.Repository;

namespace DataSharing.SendTask
{
    /// <summary>
    /// 
    /// </summary>
    public class TaskOtherPlatformsJob : IJob, IDisposable
    {
        private readonly IMapper _mapper;
        private readonly ILogger<TaskOtherPlatformsJob> _logger;
        private readonly IRepository<DsWaitSendTaskOtherPlatforms> _waitSendTaskOtherPlatformsRepository;
        private readonly ISendTaskDataService _sendTaskDataService;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="mapper"></param>
        /// <param name="logger"></param>
        /// <param name="waitSendTaskOtherPlatformsRepository"></param>
        public TaskOtherPlatformsJob(IMapper mapper,
            ILogger<TaskOtherPlatformsJob> logger,
            IRepository<DsWaitSendTaskOtherPlatforms> waitSendTaskOtherPlatformsRepository,
            ISendTaskDataService sendTaskDataService)
        {
            _mapper = mapper;
            _logger = logger;
            _waitSendTaskOtherPlatformsRepository = waitSendTaskOtherPlatformsRepository;
            _sendTaskDataService = sendTaskDataService;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="context"></param>
        /// <returns></returns>
        public async Task Execute(IJobExecutionContext context)
        {
            //加载数据
            var tasks = await _waitSendTaskOtherPlatformsRepository.Queryable()
               .Where(d => d.State == EWaitSendTaskState.WaitPush && d.SendTimes <= 6)
               .OrderBy(d => d.CreationTime)
               .Take(100)
               .ToListAsync(context.CancellationToken);
            if (tasks.Count != 0)
            {
                //处理推送数据
                foreach (var sendTask in tasks)
                {
                    //状态更改为推送中
                    sendTask.State = EWaitSendTaskState.Pushing;
                    //使用乐观锁，控制数据
                    if (await _waitSendTaskOtherPlatformsRepository.Updateable(sendTask).ExecuteCommandWithOptLockAsync() > 0)
                    {
                        //处理其他平台推送
                        await _sendTaskDataService.SendTask(sendTask, context.CancellationToken);
                    }
                }

            }
        }

        public void Dispose()
        {

        }
    }
}
